@@ -12,7 +12,7 @@ extern SEXP _microseq_read_fasta(SEXP);
 extern SEXP _microseq_read_fastq(SEXP);
 extern SEXP _microseq_read_fastq_Sanger(SEXP);
 extern SEXP _microseq_revComp(SEXP, SEXP);
-extern SEXP _microseq_transl(SEXP);
+extern SEXP _microseq_transl(SEXP, SEXP);
 extern SEXP _microseq_write_fasta(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _microseq_write_fastq(SEXP, SEXP, SEXP, SEXP);
 
@@ -21,7 +21,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"_microseq_read_fastq",        (DL_FUNC) &_microseq_read_fastq,        1},
     {"_microseq_read_fastq_Sanger", (DL_FUNC) &_microseq_read_fastq_Sanger, 1},
     {"_microseq_revComp",           (DL_FUNC) &_microseq_revComp,           2},
-    {"_microseq_transl",            (DL_FUNC) &_microseq_transl,            1},
+    {"_microseq_transl",            (DL_FUNC) &_microseq_transl,            2},
     {"_microseq_write_fasta",       (DL_FUNC) &_microseq_write_fasta,       4},
     {"_microseq_write_fastq",       (DL_FUNC) &_microseq_write_fastq,       4},
     {NULL, NULL, 0}
